aboutsummaryrefslogtreecommitdiff
path: root/devtools/create_mortdat
diff options
context:
space:
mode:
Diffstat (limited to 'devtools/create_mortdat')
-rw-r--r--devtools/create_mortdat/create_mortdat.cpp21
-rw-r--r--devtools/create_mortdat/create_mortdat.h2
-rw-r--r--devtools/create_mortdat/gametext.h34
-rw-r--r--devtools/create_mortdat/menudata.h14
4 files changed, 52 insertions, 19 deletions
diff --git a/devtools/create_mortdat/create_mortdat.h b/devtools/create_mortdat/create_mortdat.h
index 8c210d32d9..1ebbbe37e0 100644
--- a/devtools/create_mortdat/create_mortdat.h
+++ b/devtools/create_mortdat/create_mortdat.h
@@ -24,7 +24,7 @@
*/
#define VERSION_MAJOR 1
-#define VERSION_MINOR 0
+#define VERSION_MINOR 1
enum AccessMode {
kFileReadMode = 1,
diff --git a/devtools/create_mortdat/gametext.h b/devtools/create_mortdat/gametext.h
index b1809c614c..4f7b1f9776 100644
--- a/devtools/create_mortdat/gametext.h
+++ b/devtools/create_mortdat/gametext.h
@@ -505,31 +505,31 @@ const char *gameDataEn[] = {
"$",
"YOUR MOVE$",
" attach$",
- " wait$",
- " force$",
- " sleep$",
- " listen$",
- " enter$",
" close$",
- " search$",
- " knock$",
- " scratch$",
- " read$",
" eat$",
- " place$",
- " open$",
- " take$",
+ " enter$",
+ " force$",
+ " knock$",
+ " leave$",
+ " lift$",
+ " listen$",
" look$",
+ " open$",
+ " place$",
+ " read$",
+ " scratch$",
+ " search$",
+ " sleep$",
" smell$",
" sound$",
- " leave$",
- " lift$",
+ " take$",
" turn$",
+ " wait$",
" hide yourself$",
- " search$",
- " read$",
- " put$",
" look$",
+ " put$",
+ " read$",
+ " search$",
" Leo$",
" Pat$",
" Guy$",
diff --git a/devtools/create_mortdat/menudata.h b/devtools/create_mortdat/menudata.h
index aa4557b336..a927d31757 100644
--- a/devtools/create_mortdat/menudata.h
+++ b/devtools/create_mortdat/menudata.h
@@ -76,4 +76,18 @@ const char *menuDataEn =
"@@@ @@@ @@@ @@@ "
" ";
+const int verbsFr[26] = { 0x301, 0x302, 0x303, 0x304, 0x305, 0x306, 0x307, 0x308,
+ 0x309, 0x30a, 0x30b, 0x30c, 0x30d, 0x30e, 0x30f, 0x310,
+ 0x311, 0x312, 0x313, 0x314, 0x315, 0x401, 0x402, 0x403,
+ 0x404, 0x405 };
+
+const int verbsEn[26] = { 0x301, 0x307, 0x30c, 0x306, 0x303, 0x309, 0x313, 0x314,
+ 0x305, 0x310, 0x30e, 0x30d, 0x30b, 0x30a, 0x308, 0x304,
+ 0x311, 0x312, 0x30f, 0x315, 0x302, 0x401, 0x405, 0x404,
+ 0x403, 0x402 };
+
+const int verbsDe[26] = { 0x30a, 0x310, 0x313, 0x301, 0x315, 0x308, 0x303, 0x306,
+ 0x30c, 0x311, 0x314, 0x309, 0x30b, 0x30f, 0x30e, 0x304,
+ 0x307, 0x30d, 0x312, 0x302, 0x305, 0x405, 0x402, 0x404,
+ 0x403, 0x401 };
#endif
diff --git a/devtools/create_mortdat/create_mortdat.cpp b/devtools/create_mortdat/create_mortdat.cpp
index f12a69bd37..00b9b1ce4a 100644
--- a/devtools/create_mortdat/create_mortdat.cpp
+++ b/devtools/create_mortdat/create_mortdat.cpp
@@ -205,7 +205,7 @@ void writeGameStrings() {
* Write out the data for the English menu
*/
void writeMenuBlock() {
// Write out a section header to the output file and the font data
const char menuHeader[4] = { 'M', 'E', 'N', 'U' };
outputFile.write(menuHeader, 4); // Section Id
outputFile.writeWord(strlen(menuDataEn) / 8); // Section size
@@ -226,10 +226,29 @@ void writeMenuBlock() {
}
}
+void writeVerbNums(const int *verbs, int languageId) {
+ // Write out a section header to the output file
+ const char menuHeader[4] = { 'V', 'E', 'R', 'B' };
+ outputFile.write(menuHeader, 4); // Section Id
+ int size = 52 + 1; // Language code + 26 words
+ outputFile.writeWord(size);
+
+ outputFile.writeByte(languageId);
+ for (int i = 0; i < 26; i++)
+ outputFile.writeWord(verbs[i]);
+}
+
+void writeMenuVerbs() {
+ writeVerbNums(verbsEn, 1);
+ writeVerbNums(verbsFr, 0);
+ writeVerbNums(verbsDe, 2);
+}
+
void process() {
writeFontBlock();
writeGameStrings();
writeEngineStrings();
+ writeMenuVerbs();
writeMenuBlock();
}
@@ -205,7 +205,7 @@ void writeGameStrings() {
*/
void writeMenuBlock() {
- // Write out a section header to the output file and the font data
+ // Write out a section header to the output file and the menu data
const char menuHeader[4] = { 'M', 'E', 'N', 'U' };
outputFile.write(menuHeader, 4); // Section Id